@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package GitHub::MergeVelocity;
-$GitHub::MergeVelocity::VERSION = '0.000002';
+$GitHub::MergeVelocity::VERSION = '0.000003';
 use CHI;
 use CLDR::Number::Format::Percent;
 use GitHub::MergeVelocity::Repository;
@@ -72,8 +72,8 @@ has _mech => (
 );
 
 has url => (
-    is     => 'ro',
-    isa    => ArrayRef,
+    is       => 'ro',
+    isa      => ArrayRef,
     required => 1,
 );
 
@@ -112,7 +112,7 @@ sub _build_mech {
         $mech = WWW::Mechanize->new;
     }
 
-    debug_ua($mech, 7) if $self->debug_useragent;
+    debug_ua( $mech, 7 ) if $self->debug_useragent;
     return $mech;
 }
 
@@ -180,11 +180,14 @@ sub _columns_for_state {
     my $age    = $state . '_age';
 
     return (
-        sprintf( '%i (%s)',
-            $report->$state,
-            $self->_format_percent( $report->percentage_in_state($state) ) ),
-        sprintf( '%i (%s/PR)',
-            $report->$age, $report->average_age_for_state($state) ),
+        $report->$state
+        ? sprintf( '%s (%i)',
+            $self->_format_percent( $report->percentage_in_state($state) ),
+            $report->$state )
+        : 0,
+        $report->$age ? sprintf( '%s/PR (%i)',
+            $report->average_age_for_state($state),
+            $report->$age ) : 0,
     );
 }
 
@@ -201,7 +204,7 @@ GitHub::MergeVelocity - Determine how quickly your pull request might get merged
 
 =head1 VERSION
 
-version 0.000002
+version 0.000003
 
 =head1 SYNOPSIS
 
